@@ -1,22 +1,15 @@
 #[cfg(not(feature = "docs-rs"))]
 #[cfg(feature = "static-fallback")]
 fn download_and_build() {
-    let download = librarian::download_or_find_file(
-        "https://github.com/IAIK/Picnic/archive/refs/tags/v3.0.5.tar.gz",
-        None,
-    )
-    .expect("Failed to download Picnic");
-
-    let src = librarian::extract_archive(&download, None)
-        .expect("Failed to extract Picnic source")
-        .join("Picnic-3.0.5");
-
+    let src = std::path::Path::new("Picnic");
     let target = std::env::var("TARGET").unwrap();
     let profile = std::env::var("PROFILE").unwrap();
 
     let mut build = cc::Build::new();
     build.static_flag(true);
     build.define("PICNIC_STATIC", None);
+    build.define("NDEBUG", None);
+    build.define("WITH_KECCAK_X4", None);
     build.include(src.join("sha3"));
     build.include(src.join("sha3/opt64"));
     if profile == "release" {
@@ -31,7 +24,7 @@ fn download_and_build() {
         }
     }
     if cfg!(target_feature = "neon") {
-        build.define("WITH_SIMD_OPT", None);
+        build.define("WITH_OPT", None);
         build.define("WITH_NEON", None);
     }
 
